@@ -5,7 +5,7 @@ from .error_handling import SearchNotWork, NoResultFound
 
 class Charapedia:
   def __init__(self, char: str):
-    
+    char = ''.join(char)
     try:
       mal_char_id = search('site:myanimelist.net {} character info inurl:/character/'.format(char), num_results=0)
     except SearchNotWork:
@@ -29,10 +29,10 @@ class Charapedia:
     self.name = name or None
 #url name
     url = result['url']
-    self.url = url
+    self.url = url or None
 #image url
     image_url = result['image_url']
-    self.image_url = image_url
+    self.image_url = image_url or None
 #about
     about = result['about']
     if 'No biography written.' in about:
